==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebCircularProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebCircularProgressDescription } from "./WebCircularProgressDescription";
/**
 * @hidden
 */
export let WebCircularProgressDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCircularProgressDescriptionMetadata extends Base {
        static b(a) {
            if (WebCircularProgressDescriptionMetadata.a == null) {
                WebCircularProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCircularProgressDescriptionMetadata.c(WebCircularProgressDescriptionMetadata.a);
            }
            if (a.j(WebCircularProgressDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCircularProgressDescriptionMetadata.a);
        }
        static c(a) {
            WebProgressBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CircularProgress");
            a.item("__tagNameWC", "String:igc-circular-progress");
        }
        static d(a) {
            WebCircularProgressDescriptionMetadata.b(a);
            a.aa("WebCircularProgress", () => new WebCircularProgressDescription());
            a.z("WebCircularProgress", WebCircularProgressDescriptionMetadata.a);
        }
    }
    WebCircularProgressDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCircularProgressDescriptionMetadata, 'WebCircularProgressDescriptionMetadata');
    WebCircularProgressDescriptionMetadata.a = null;
    return WebCircularProgressDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCircularProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebCircularProgressDescription } from "./WebCircularProgressDescription";
/**
 * @hidden
 */
export let WebCircularProgressDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCircularProgressDescriptionMetadata extends Base {
        static b(a) {
            if (WebCircularProgressDescriptionMetadata.a == null) {
                WebCircularProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCircularProgressDescriptionMetadata.c(WebCircularProgressDescriptionMetadata.a);
            }
            if (a.k(WebCircularProgressDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCircularProgressDescriptionMetadata.a);
        }
        static c(a) {
            WebProgressBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CircularProgress");
            a.item("__tagNameWC", "String:igc-circular-progress");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebCircularProgressDescriptionMetadata.b(a);
            a.ac("WebCircularProgress", () => new WebCircularProgressDescription());
            a.ab("WebCircularProgress", WebCircularProgressDescriptionMetadata.a);
        }
    }
    WebCircularProgressDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCircularProgressDescriptionMetadata, 'WebCircularProgressDescriptionMetadata');
    WebCircularProgressDescriptionMetadata.a = null;
    return WebCircularProgressDescriptionMetadata;
})();
